@@ -1,3 +1,4 @@
+import os
 from argparse import Namespace
 from pathlib import Path
 
@@ -5,12 +6,13 @@ from dstack.api.backend import get_current_remote_backend, get_local_backend
 from dstack.api.repo import load_repo_data
 from dstack.api.run import RunNotFoundError, TagNotFoundError, get_tagged_run_name
 from dstack.cli.commands import BasicCommand
+from dstack.cli.common import console
 from dstack.core.error import BackendError, check_config, check_git
 
 
 class PushCommand(BasicCommand):
     NAME = "push"
-    DESCRIPTION = "Copy a run and its artifacts from local to remote"
+    DESCRIPTION = "Push artifacts of a local run"
 
     def __init__(self, parser):
         super().__init__(parser)
@@ -28,21 +30,24 @@ class PushCommand(BasicCommand):
     def _command(self, args: Namespace):
         repo_data = load_repo_data()
         local_backend = get_local_backend()
+        remote_backend = get_current_remote_backend()
+        if remote_backend is None:
+            console.print(f"No remote backend configured. Run `dstack config`.")
+            exit(1)
+
         try:
             run_name, tag_head = get_tagged_run_name(
                 repo_data, local_backend, args.run_name_or_tag_name
             )
         except TagNotFoundError as e:
-            print(f"Cannot find the local tag '{args.run_name_or_tag_name}'")
+            console.print(f"Cannot find the local tag '{args.run_name_or_tag_name}'")
             exit(1)
         except RunNotFoundError as e:
-            print(f"Cannot find the local run '{args.run_name_or_tag_name}'")
+            console.print(f"Cannot find the local run '{args.run_name_or_tag_name}'")
             exit(1)
 
         jobs = local_backend.list_jobs(repo_data, run_name)
 
-        remote_backend = get_current_remote_backend()
-
         if tag_head is not None:
             try:
                 remote_backend.add_tag_from_run(
@@ -58,19 +63,21 @@ class PushCommand(BasicCommand):
         run_artifacts = local_backend.list_run_artifact_files(
             repo_address=repo_data, run_name=run_name
         )
-        unique_artifacts = {(a.job_id, a.name) for a in run_artifacts}
 
-        for job_id, artifact_name in unique_artifacts:
+        for artifact in run_artifacts:
             remote_backend.upload_job_artifact_files(
                 repo_address=repo_data,
-                job_id=job_id,
-                artifact_name=artifact_name,
+                job_id=artifact.job_id,
+                artifact_name=artifact.name,
+                artifact_path=artifact.path,
                 local_path=Path(
-                    local_backend.get_artifacts_path(repo_data), job_id, artifact_name
+                    local_backend.get_artifacts_path(repo_data),
+                    artifact.job_id,
+                    artifact.path,
                 ),
             )
 
         for job in jobs:
-            remote_backend.store_job(job)
+            remote_backend.create_job(job)
 
-        print("Push completed")
+        console.print("Push completed")
