@@ -38,7 +38,7 @@ class Configurator(ABC):
         pass
 
     @abstractmethod
-    def configure_hub(self, data: Dict):
+    async def configure_hub(self, data: Dict):
         pass
 
     @abstractmethod
@@ -46,5 +46,5 @@ class Configurator(ABC):
         pass
 
     @abstractmethod
-    def parse_args(self, args: list = []):
+    def register_parser(self, parser):
         pass
