@@ -1,31 +1,24 @@
 from typing import List, Optional
 
+from pydantic import BaseModel
+
 from dstack.core.job import Job
 
 
-class Gpu:
-    def __init__(self, name: str, memory_mib: int):
-        self.memory_mib = memory_mib
-        self.name = name
+class Gpu(BaseModel):
+    name: str
+    memory_mib: int
 
     def __str__(self) -> str:
         return f'Gpu(name="{self.name}", memory_mib={self.memory_mib})'
 
 
-class Resources:
-    def __init__(
-        self,
-        cpus: int,
-        memory_mib: int,
-        gpus: Optional[List[Gpu]],
-        interruptible: bool,
-        local: bool,
-    ):
-        self.cpus = cpus
-        self.memory_mib = memory_mib
-        self.gpus = gpus
-        self.interruptible = interruptible
-        self.local = local
+class Resources(BaseModel):
+    cpus: int
+    memory_mib: int
+    gpus: Optional[List[Gpu]]
+    interruptible: bool
+    local: bool
 
     def __str__(self) -> str:
         return (
@@ -36,12 +29,11 @@ class Resources:
         )
 
 
-class Runner:
-    def __init__(self, runner_id: str, request_id: Optional[str], resources: Resources, job: Job):
-        self.runner_id = runner_id
-        self.request_id = request_id
-        self.job = job
-        self.resources = resources
+class Runner(BaseModel):
+    runner_id: str
+    request_id: Optional[str]
+    resources: Resources
+    job: Job
 
     def serialize(self) -> dict:
         resources = {
@@ -68,14 +60,17 @@ class Runner:
     @staticmethod
     def unserialize(data: dict):
         return Runner(
-            data["runner_id"],
-            data.get("request_id"),
-            Resources(
-                data["resources"]["cpus"],
-                data["resources"]["memory_mib"],
-                [Gpu(g["name"], g["memory_mib"]) for g in data["resources"]["gpus"]],
-                data["resources"]["interruptible"] is True,
-                data["resources"].get("local") is True,
+            runner_id=data["runner_id"],
+            request_id=data.get("request_id"),
+            resources=Resources(
+                cpus=data["resources"]["cpus"],
+                memory_mib=data["resources"]["memory_mib"],
+                gpus=[
+                    Gpu(name=g["name"], memory_mib=g["memory_mib"])
+                    for g in data["resources"]["gpus"]
+                ],
+                interruptible=data["resources"]["interruptible"] is True,
+                local=data["resources"].get("local") is True,
             ),
-            Job.unserialize(data["job"]),
+            job=Job.unserialize(data["job"]),
         )
